/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus;

/**
 * <p>
 *  <code>InvalidCollectionTypeException</code> is an extension of 
 *    <code>{@link ZeusException}</code> that provides information
 *    about an invalid collection type specified.
 * </p>
 * 
 * @author Brett McLaughlin
 */
public class InvalidCollectionTypeException extends ZeusException {
    
    /**
     * <p>
     *  This indicates that an invalid collection type was supplied.
     * </p>
     */    
    public InvalidCollectionTypeException()  {
        super("An illegal or unsupported collection type was specified.");
    }
    
    /**
     * <p>
     *  This indicates that an invalid collection type was supplied.
     * </p>
     *
     * @param collectionType the invalid collection type specified.
     */    
    public InvalidCollectionTypeException(String collectionType)  {
        super("An illegal or unsupported collection type, '" + collectionType +
            "', was specified.");
    }
}
