/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus;

// Zeus imports
import org.enhydra.zeus.transform.TransformerOptions;
import org.enhydra.zeus.util.ClassUtils;

/**
 * <p>
 *  <code>ZeusDefaults</code> defines constants used throughout
 *    the rest of the Zeus code base.
 * </p>
 *
 * @author Brett McLaughlin
 */
public class ZeusDefaults {
    
    /** XML Name for PCDATA elements */
    public static final String PCDATA_XML_NAME = "PCDATA";
    
    /** Java Name for PCDATA variable */
    public static final String PCDATA_JAVA_NAME = "value";

    /** Name of the Zeus element XML name field. */
    public static final String XML_NAME_FIELD = "ZEUS_XML_NAME";

    /** Name of field for Zeus attributes array */
    public static final String ATTRIBUTE_ARRAY_FIELD = "ZEUS_ATTRIBUTES";

    /** Name of field for Zeus elements array */
    public static final String ELEMENT_ARRAY_FIELD = "ZEUS_ELEMENTS";
    
    /** Name prefix for Zeus internal variables */
    public static final String ZEUS_INTERNAL_PREFIX = "zeus_";

    /** The default (and current) XML Schema namespace URI */
    public static final String SCHEMA_NAMESPACE_URI =
        "http://www.w3.org/2001/XMLSchema";
        
    /** Default XML parser to use */
    public static final String DEFAULT_PARSER =
        "org.apache.xerces.parsers.SAXParser";
        
    /** The default options for a Zeus Transformer */
    public static final TransformerOptions DEFAULT_TRANSFORMER_OPTIONS =
        new TransformerOptions("", ClassUtils.COLLECTION_TYPE_LIST);
        
    /** The default state for validation */
    public static final Boolean DEFAULT_VALIDATION_STATE =
        new Boolean(false);
        
    /** The system property to use for setting validation */
    public static final String VALIDATION_SYSTEM_PROPERTY =
        "org.enhydra.zeus.validation";
        
    /* -------------- Comments and other textual defaults ----------------- */
    public static final String GENERATED_CLASS_COMMENT = new StringBuffer()
        .append("/**\n")
        .append(" * This class was generated from a set of XML constraints\n")
        .append(" *   by the Enhydra Zeus XML Data Binding Framework. All\n")
        .append(" *   source code in this file is constructed specifically\n")
        .append(" *   to work with other Zeus-generated classes. If you\n")
        .append(" *   modify this file by hand, you run the risk of breaking\n")
        .append(" *   this interoperation, as well as introducing errors in\n")
        .append(" *   source code compilation.\n")
        .append(" *\n")
        .append(" * * * * * MODIFY THIS FILE AT YOUR OWN RISK * * * * *\n")
        .append(" *\n")
        .append(" * To find out more about the Enhydra Zeus framework, you\n")
        .append(" *   can point your browser at <http://zeus.enhydra.org>\n")
        .append(" *   where you can download releases, join and discuss Zeus\n")
        .append(" *   on user and developer mailing lists, and access source\n")
        .append(" *   code. Please report any bugs through that website.\n")
        .append(" */\n")
        .toString();
}

