/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus.util;

import org.enhydra.zeus.Binding;
import org.enhydra.zeus.ZeusException;

/**
 * <p>
 *  <code>UnsupportedSchemaTypeException</code> is an extension of 
 *    <code>{@link ZeusException}</code> that provides information
 *    about a schema type that has been supplied, but is not supported by
 *    Zeus.
 * </p>
 * 
 * @author Brett McLaughlin
 */
public class UnsupportedSchemaTypeException extends ZeusException {
    
    /**
     * <p>
     *  This indicates that an invalid schema type was supplied to
     *    a Zeus method.
     * </p>
     */    
    public UnsupportedSchemaTypeException()  {
        super("The supplied schema type is not currently supported by Zeus.");
    }
    
    /**
     * <p>
     *  This indicates that an invalid schema type was supplied to
     *    a Zeus method.
     * </p>
     *
     * @param schemaType the schema type that is unsupported.
     */    
    public UnsupportedSchemaTypeException(String schemaType)  {
        super("The supplied schema type, '" + schemaType + "', is not " +
            "currently supported by Zeus.");
    }
}
