/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus.binder;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.IOException;
import java.io.Reader;
import java.io.StringReader;
import java.util.List;

// Zeus imports
import org.enhydra.zeus.source.StreamSource;

// JUnit imports
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * <p>
 *  <code>SchemaBinderTest</code> provides rudimentary tests for the
 *    <code>{@link DTDBInder}</code> class. 
 * </p>
 *
 * @author Brett McLaughlin
 */
public class SchemaBinderTest extends TestCase {

    /**
     * <p>
     *  Creates a new <code>SchemaBinderTest</code> instance.
     *    Required by JUnit. <CODE>testName</CODE>
     *    is simply the name of the test.
     * </p>
     *
     * @param testName a <code>String</code> value
     */
    public SchemaBinderTest(String testName) {
        super(testName);
    }

    /**
     * <p>
     *  This method maeks it easier to call these
     *    tests dynamically.
     * </p>
     *
     * @return <code>TestSuite</code> - corresponds to this 
     *         <code>TestCase</code>.
     */
    public static Test suite() {
        return new TestSuite(SchemaBinderTest.class);
    }

    /**
     * <p>
     *  Test the various <CODE>{@link SchemaBinder}</CODE> 
     *    constructors.
     * </p>
     */
    public void testConstructors() {
        String systemID = "file:///test/system/ID.xml";
        FileInputStream in = null;
        try {
            in =  new FileInputStream(new File("bin/build.sh"));
        } catch (FileNotFoundException neverHappens) { }
        StreamSource ss = new StreamSource(in, systemID);
        SchemaBinder binder = new SchemaBinder(ss);
        
        ss = new StreamSource(in);
        binder = new SchemaBinder(ss);
        
        StringReader reader = new StringReader("Test Input Reader");
        ss = new StreamSource(reader, systemID);
        binder = new SchemaBinder(ss);
        
        ss = new StreamSource(reader);
        binder = new SchemaBinder(ss);
    }
    
    /**
     * <p>
     *  Rudimentary test of the 
     *    <CODE>{@link SchemaBinder#getBindings()}</CODE> method.
     *    This is a negative test. Getting the schema bindings should
     *    fail and this should be detected and handled correctly. 
     * </p>
     */
    public void testGetBindingsNegative() {
        boolean caught = false;
        try {
            String systemID = "file:///test/system/ID.dtd";
            FileInputStream in = null;
            try {
                in =  new FileInputStream(new File("bin/build.sh"));
            } catch (FileNotFoundException neverHappens) { }
            StreamSource ss = new StreamSource(in, systemID);
            SchemaBinder binder = new SchemaBinder(ss);
            List bindings = binder.getBindings();
        } catch (IOException e) {
            // Failure is the desired behavior
            caught = true;
        } finally {
            assertTrue(caught);
        }
    }

    /**
     * <p>
     *  Rudimentary positive test of the 
     *    <CODE>{@link SchemaBinder#getBindings()}</CODE> method.
     *    A viable list of bindings should be returned.
     * </p>
     */
    public void testGetBindingsPositive() {
        // I need a robust way to get an XML DTD here
        // What is the plan for system properties type configuration?
    }
}
